"""Grid Configuration Monitoring Client WN

This module starts the Worker Node Client for Grid Monitoring.

Author: Thomas Low <thomas.low@cern.ch>
Edited by: Danica Stojiljkovic <danica@scl.rs>
"""

__VERSION__ = "0.1.2"

import os, sys

os.environ['GLITE_HOME'] = os.environ.get('GLITE_HOME','/opt/glite')
os.environ['GLITE_SWAT_HOME'] = os.environ.get('GLITE_SWAT_HOME',os.environ['GLITE_HOME'])
os.environ['GLITE_SWAT_ETC'] = os.environ.get('GLITE_SWAT_ETC',os.environ['GLITE_SWAT_HOME']+'/etc/glite-swat')
sys.path.insert(0,os.environ['GLITE_SWAT_HOME']+'/lib/python/')


import getopt
try:
    import logging
except:
    import swatc.logging as logging
log = logging.getLogger(__name__)

from swatc.common import logger, config, event

def _loadConfig():
	"""Loads the configuration file of the client into a variable."""
	opts, _ = _parseArguments()
	conf = config.load('glite-swat-client-wn.conf', 'GLITE_SWAT_ETC', 
							opts.get('c'), 'GLITE_SWAT_CLIENT_WN_CONFIG')		
	if opts.has_key('v'):
		conf.set('logger','level','10')
	if opts.has_key('f'):
		conf.set('swatc.clients.wn.producer.proctester.ProcTester', 'forceExecution','1')	
	return conf


def _parseArguments():
	"""Parses some basic arguments."""
	try:
		opts, args = getopt.getopt(sys.argv[1:],
			"hvfc:", ["help", "verbose", "force", "config=", "version"])
	except getopt.GetoptError, err:
		_printUsage(str(err))
		sys.exit(2)
	options = {}
	for (o,a) in opts:
		if o == "--version":
			print os.path.basename(sys.argv[0]),"v"+__VERSION__
			sys.exit(0)
		options[o.replace('-','')[0]] = a
	if args:
		_printUsage("no arguments allowed")
		sys.exit(2)
	if 'h' in options.keys():
		_printUsage()
		sys.exit(0)
	return options, args


def _printUsage(error=''):
	"""Prints the Usage if necessary."""
	d = { 	'error' : error, 
			'name'  : os.path.basename(sys.argv[0]),
			'w' 	: '\033[1;37m', #set console text to white
			'ul'	: '\033[4m', #underline console text
			'n'		: '\033[m' } #reset console formatting
	if error:
		print "%(w)sERROR:%(n)s\t %(error)s\n" % d
	print """%(w)sNAME:%(n)s
\t %(name)s - Grid Configuration Monitoring: Client Worker Node

%(w)sSYNOPSIS: %(n)s
\t %(name)s [-hv] [-c %(ul)sconfig_file%(n)s]

%(w)sOPTIONS:%(n)s
\t -h, --help
\t\t Print this help text and exit.
\t -v, --verbose
\t\t Be more verbose
\t -c, --config %(ul)spath%(n)s
\t\t Use alternative path to configuration file for %(name)s
\t -f, --force 
\t\t Forces execution of every test disregarding execution probability
\t --version
\t\t Print version of %(name)s
""" % d


if __name__ == '__main__':
	run()
	
