"""Test Consumer Classes

This module provides a special Consumer/Producer class, which will collect
information about the client itself. It also manages the memory file.

Author: Thomas Low <thomas.low@cern.ch>
"""

import time

import producer, consumer, util, os

try:
	import logging
except:
	import swatc.logging as logging
log = logging.getLogger(__name__)

from swatc.common import test, logger, testproducer, testconsumer
from swatc.clients.wn import client
from producer import memory

class ClientTester(testproducer.TestProducer, testconsumer.TestConsumer):

	#Class variable to transfer test names from consumer instace to producer.
	testList = []

	def __init__(self, level=logging.ERROR, memory="/tmp/glite-swat-client-wn.mem"):
		"""Inits the ClientTester.
		
		LEVEL specifies the level of log messages which will be sent as a test.
		MEMORY is the path to the memory file.
		"""				
		#get parameters
		self.level = level
		self.memoryFile = memory
		#init variables
		self.started = time.time()
		self.event = None
		self.memory = None
		#capture logging
		self.getLogList = logger.setupListLogging(self.level)

		
	def setup(self):
		#read memory file
		self.memory = memory.TestMemory(self.memoryFile)
		if not self.memory.getMemoryTime():
			log.debug("Memory file %s not found" % self.memoryFile)		
			
	def consume(self, test):
		#store the list of test names
		ClientTester.testList.append(test.testName)
		
	def run(self, event):
		self.event = event
		
	def cleanup(self):
		if self.event:
			#send a message containing debugging information of the client
			ended = time.time()
			ClientTester.testList.append("wn_client")
			t = test.Test("wn_client")
			t.executionStarttime = repr(self.started)
			t.executionEndtime = repr(ended)
			t.testVersion = str(client.__VERSION__)
			t.hostname	= util.hostname
			t.hostid	= util.hostid
			t.executionUnit = "ClientTester"
			t.executionTime = repr(ended-self.started)
			t.summary = round(ended-self.started,2)
			l = self.getLogList
			if l:
				t.detailsdata = "\n".join(l)
			t.testlist = str(ClientTester.testList)
			if self.memory and self.memory.getMemoryTime():
				t.memoryAvailable = "1"
				t.memoryLastExecution = repr(self.memory.getMemoryTime())
				t.timeSinceLastExecution = repr(int(time.time()-self.memory.getMemoryTime()))
			else:
				t.memoryAvailable = "0"
			self.event(t)
			
			#update the memory file for executed tests
			if self.memory:
				for t in ClientTester.testList:
					self.memory.updateTest(t)
				self.memory.save()
			
