"""Test Memory Class

This class loads timestamps from a file so the client is able to schedule tests 
just more accurate. (e.g. every day, but only if < 1 week since /tmp will be
deleted every week)

Author: Thomas Low <thomas.low@cern.ch>
"""

IDENTITY_STRING = "###GLITE-SWAT-MEMORY-FILE###"

import os, time

class TestMemory:
	
	def __init__(self, path):
		"""Create dictionary of timestamps."""
		self.path = path		
		try:
			f = open(path, "r")
			self.d, self.t = self._convertToDict(f.readlines())
			f.close()
		except:
			self.d = {}
			self.t = None
	
	def has_key(self, key):
		return self.d.has_key(key)
		
	def __getitem__(self, key):
		return 	self.d[key]
		
	def get(self, key, default=None):
		return self.d.get(key, default)
								
	def getMemoryTime(self):
		"""Get last execution time of client."""
		return self.t
		
	def updateTest(self, test):
		"""Update timestamp of a certain test."""
		self.d[test] = int(time.time())
		
	def _convertToDict(self, lines):
		"""Load file and store timestamps in dictionary."""
		d = {}
		t = None
		if lines[0].strip() != IDENTITY_STRING:
			raise Exception("Not a valid memory File")
		else:
			t = int(lines[1])
			for line in lines[2:]:
				name, stamp = line.split(":", 1)
				d[name] = int(stamp)
		return d, t
				
	def save(self):
		"""Save dictionary to file."""
		try:
			f = open(self.path, "w")
			f.write(IDENTITY_STRING+"\n")
			f.write(str(int(time.time()))+"\n")
			for k,v in self.d.items():
				f.write("%s:%s\n" % (str(k),str(v)))
				f.close()
		except:
			pass
		
		
