"""Python Producer Class

This module provides a Python-Producer Class to create new tests.

PyTester executes a set of python modules within a directory and forwards their
produced test classes.

Author: Thomas Low <thomas.low@cern.ch>
"""

import sys, os, time, os.path, tempfile, imp, shutil
try:
	import logging
except:
	import swatc.logging as logging
log = logging.getLogger(__name__)

from swatc.common.testproducer import TestProducer
from swatc.common import test, openssl, message
from swatc.common.test import Test

from swatc.clients.wn import util

class PyTester(TestProducer):

	def __init__(self, directories):
		"""Init.
		
		DIRECTORIES are paths to directories separated by colons.
		"""
		self.directories = directories.split(":")
		self.testlist = []
		
	def _getModule(self, path):
		module = os.path.basename(path)[:-3]
		fp, name, smt = imp.find_module(module, [os.path.dirname(path)])
		try:
			m = imp.load_module("pytester_"+module, fp, name, smt)
		finally:
			fp.close()
		return m
		
	def setup(self):
		"""Loads the python test-classes from the directory."""
		for directory in self.directories:
			if os.path.isdir(directory):
				dTest_path = os.path.join(directory, "testdef.default")
				dTest = self._createDefaultTestFromFile(dTest_path)
				for f in os.listdir(directory):
					path = os.path.join(directory,f)
					if f[-3:] == ".py" and os.access(path, os.F_OK) \
							and not os.access(path, os.X_OK):
						#create a new test for each *.py file
						t = Test("pytest")
						t.update(message.messageToDict(dTest))
						t.executionFile = path
						self.testlist.append(t)
			else:
				log.error("directory %s does not exist" % directory)
				
	def _createDefaultTestFromFile(self, path):
		if not os.path.exists(path):
			return message.Message()
		try:
			lines = open(path, 'r').readlines()
			return message.stringToMessage("".join(lines))
		except Exception, err:
			log.error("%s : %s" % (os.path.basename(path), err))
			return message.Message()
		
	def run(self, event):
		for t in self.testlist:
			#load and execute getTest() method of each *.py file
			try:
				m = self._getModule(t.executionFile)
				if m.__dict__.has_key('getTest'):
					starttime = time.time()
					tmp = m.getTest()
					if tmp: #merge results with testdef.default tuples
						endtime = time.time()
						final = Test(tmp.testName)
						final.update(test.testToDict(t))
						final.update(test.testToDict(tmp))
						final.executionCommand = t.executionFile+".getTest()"
						final.executionUnit = "PyTester"
						final.executionEndtime = repr(endtime)
						final.executionTime = repr(endtime-starttime)
						final.executionStarttime = repr(starttime)
						final.hostname	= util.hostname
						final.hostid	= util.hostid
						event(final)
			except Exception, err:
				log.exception(err)	

